@@ -424,9 +424,9 @@ else:
     path="C:\\Users\\"+os.getlogin()+"\\Desktop\\output.txt"
     py=path="C:\\Users\\"+os.getlogin()+"\\Desktop\\output.py"
     f=open(path,'w')
-    f1=open(py,'w')
+    with open(py,'w') as f1:
+        print(s,file=f1)    
     print(s,file=f)
-    print(s,file=f1)
     f.close()
     f1.close()
 '''
